@@ -21,3 +21,6 @@ export * from './progress/progress-popup';
 export * from './repo';
 export * from './revision';
 export * from './timestamp';
+export * from './spinner';
+export * from './badge-panel/badge-panel';
+export * from './number-field';
